/*
 * Copyright 2024 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.compose.material.icons.twotone

import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.materialIcon
import androidx.compose.material.icons.materialPath
import androidx.compose.ui.graphics.vector.ImageVector

public val Icons.TwoTone.Attribution: ImageVector
    get() {
        if (_attribution != null) {
            return _attribution!!
        }
        _attribution = materialIcon(name = "TwoTone.Attribution") {
            materialPath(fillAlpha = 0.3f, strokeAlpha = 0.3f) {
                moveTo(12.0f, 4.0f)
                curveToRelative(-4.42f, 0.0f, -8.0f, 3.58f, -8.0f, 8.0f)
                reflectiveCurveToRelative(3.58f, 8.0f, 8.0f, 8.0f)
                reflectiveCurveToRelative(8.0f, -3.58f, 8.0f, -8.0f)
                reflectiveCurveToRelative(-3.58f, -8.0f, -8.0f, -8.0f)
                close()
                moveTo(12.0f, 5.0f)
                curveToRelative(0.83f, 0.0f, 1.5f, 0.67f, 1.5f, 1.5f)
                reflectiveCurveTo(12.83f, 8.0f, 12.0f, 8.0f)
                reflectiveCurveToRelative(-1.5f, -0.67f, -1.5f, -1.5f)
                reflectiveCurveTo(11.17f, 5.0f, 12.0f, 5.0f)
                close()
                moveTo(14.75f, 14.5f)
                horizontalLineToRelative(-1.5f)
                lineTo(13.25f, 19.0f)
                horizontalLineToRelative(-2.5f)
                verticalLineToRelative(-4.5f)
                horizontalLineToRelative(-1.5f)
                lineTo(9.25f, 9.88f)
                curveToRelative(0.0f, -0.92f, 1.84f, -1.38f, 2.75f, -1.38f)
                reflectiveCurveToRelative(2.75f, 0.47f, 2.75f, 1.38f)
                verticalLineToRelative(4.62f)
                close()
            }
            materialPath {
                moveTo(12.0f, 2.0f)
                curveTo(6.47f, 2.0f, 2.0f, 6.47f, 2.0f, 12.0f)
                reflectiveCurveToRelative(4.47f, 10.0f, 10.0f, 10.0f)
                reflectiveCurveToRelative(10.0f, -4.48f, 10.0f, -10.0f)
                reflectiveCurveTo(17.52f, 2.0f, 12.0f, 2.0f)
                close()
                moveTo(12.0f, 20.0f)
                curveToRelative(-4.42f, 0.0f, -8.0f, -3.58f, -8.0f, -8.0f)
                reflectiveCurveToRelative(3.58f, -8.0f, 8.0f, -8.0f)
                reflectiveCurveToRelative(8.0f, 3.58f, 8.0f, 8.0f)
                reflectiveCurveToRelative(-3.58f, 8.0f, -8.0f, 8.0f)
                close()
                moveTo(12.0f, 8.5f)
                curveToRelative(-0.91f, 0.0f, -2.75f, 0.46f, -2.75f, 1.38f)
                verticalLineToRelative(4.62f)
                horizontalLineToRelative(1.5f)
                lineTo(10.75f, 19.0f)
                horizontalLineToRelative(2.5f)
                verticalLineToRelative(-4.5f)
                horizontalLineToRelative(1.5f)
                lineTo(14.75f, 9.88f)
                curveToRelative(0.0f, -0.91f, -1.84f, -1.38f, -2.75f, -1.38f)
                close()
            }
            materialPath {
                moveTo(12.0f, 6.5f)
                moveToRelative(-1.5f, 0.0f)
                arcToRelative(1.5f, 1.5f, 0.0f, true, true, 3.0f, 0.0f)
                arcToRelative(1.5f, 1.5f, 0.0f, true, true, -3.0f, 0.0f)
            }
        }
        return _attribution!!
    }

private var _attribution: ImageVector? = null
